#ifndef NT2_INCLUDE_FUNCTIONS_NEAREST_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_NEAREST_HPP_INCLUDED

#include <nt2/interpol/include/functions/nearest.hpp>

#endif
